DatabucketsEventTrackerConfig class

Properties

apiKey → String
final
baseUrl → String
final
flushInterval → int
final
flushThreshold → int
final
hashCode → int
The hash code for this object.
no setterinherited
maxEventsStored → int
final
maxFlushSize → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited