DefaultUserPropertiesHandler class

Constructors

DefaultUserPropertiesHandler.createMockHandler({required DeviceInfoService device, required AppInfoService app, required GeoInfoService geo})
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

gatherInformation() → Future<void>
getDefaultUserProperties() → Future<Map<String, Object?>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance → DefaultUserPropertiesHandler
no setter

Constants

appPropertiesKey → const String
devicePropertiesKey → const String