ExceptionTracker class

Optional exception log tracking. Records app_exception_log events when Flutter errors occur.

Constructors

ExceptionTracker()

Properties

hashCode int
The hash code for this object.
no setterinherited
onFlushNow Future<void> Function()?
Callback for immediate flush after exception.
getter/setter pair
onRecordEvent Future<void> Function(Event event)?
Callback for recording events (injected from main tracker).
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

disable() → void
enable() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

sanitizeCondition(String condition) String