AppInfoUtil class

Implemented types

Constructors

AppInfoUtil()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

gatherAppInfo() Future<Map<String, Object?>>
override
getAppId() Future<String>
getAppPlatform() String
Returns lowercase platform string matching Unity SDK convention.
getAppStore() Future<String?>
getAppVersion() Future<String?>
getInstallTimestamp() Future<int>
Returns install timestamp in milliseconds via MethodChannel.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

installTimestampLoaderOverride Future<int?> Function()?
getter/setter pair
packageInfoLoaderOverride Future<PackageInfo> Function()?
getter/setter pair
platformCallTimeout Duration
getter/setter pair

Static Methods

configureTestHooks({Future<PackageInfo> packageInfoLoader()?, Future<int?> installTimestampLoader()?, Duration? timeout}) → void
resetTestHooks() → void