DeviceInfoUtil class

Implemented types

Constructors

DeviceInfoUtil()
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

gatherDeviceInfo() → Future<Map<String, Object?>>
Gathers device info
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

packageInfoLoaderOverride ↔ Future<PackageInfo> Function()?
getter/setter pair
platformCallTimeout ↔ Duration
getter/setter pair

Static Methods

configureTestHooks({Future<PackageInfo> packageInfoLoader()?, Duration? timeout}) → void
resetTestHooks() → void