maxPayloadBytes constant
int
const maxPayloadBytes
Max total payload size per batch in bytes (256KB).
Implementation
static const int maxPayloadBytes = 256 * 1024;
Max total payload size per batch in bytes (256KB).
static const int maxPayloadBytes = 256 * 1024;