GeoInfoService class abstract

Implementers

Constructors

GeoInfoService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
Release resources held by this service (e.g. HTTP client).
fetchGeoInfo(Uri url) Future<Map<String, dynamic>>
fetchIpCountryCode() Future<String>
Returns 2-letter IP-based country code, or empty string if unavailable.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited