EventKeyValidator class

Constructors

EventKeyValidator()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

isReservedKey(String key) bool
Check if a key is a reserved SDK key.
isValidKey(String? s) bool

Constants

reservedKeys → const Set<String>
Keys reserved by the SDK — cannot be overwritten by user code.