EngagementTracker class
Tracks engagement time between events. engagement_time_msec = time since last event for regular events, 0 for session_start, first_open, app_focus_start.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getEngagementTimeMsec(
String eventName, int currentTs) → int - Get engagement time in milliseconds for the given event.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateLastEventTimestamp(
int ts) → void - Update the last event timestamp.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited