FirstOpenTracker class
Tracks first_open event with delivery confirmation. Only marks as sent after HTTP 200 acknowledgement.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
onLookupEventPresence
↔ Future<
bool?> Function(String eventName, int tsMillis)? -
getter/setter pair
-
onRecordEvent
↔ Future<
void> Function(Event event)? -
Callback for recording events (injected from main tracker).
getter/setter pair
Static Methods
-
markFirstOpenDelivered(
) → Future< void> - Mark first_open as delivered (called after HTTP 200 for batch containing first_open).
-
markFirstOpenNeedsReplay(
) → Future< void> - Check if first_open needs replay (e.g., after DB loss).
-
reconcilePendingFirstOpen(
int initTimestamp, {required Future< bool?> lookupEventPresence(String eventName, int tsMillis), Future<void> persistEvent(Event event)?, required bool allowReplayWithoutSignal}) → Future<bool> -
resetStaticState(
) → void - Reset cached static state. Must be called when the SDK is re-initialized.
-
saveFirstOpenTime(
int timeMillis) → Future< void> - Save first open time.
-
tryQueueFirstOpen(
int firstOpenTime, int initTimestamp) → Future< void> - Try to queue a first_open event.
-
tryReplayFirstOpenNow(
int initTimestamp, {Future< void> persistEvent(Event event)?}) → Future<void> - Try replaying first_open if needed, with cooldown.