EventSizeUtil class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- DELIMITER_SIZE → int
-
no setter
- delimiterSize → int
-
final
Static Methods
-
getMaxEventsUnderSizeLimit(
List< String> events) → int - Returns the maximum number of events that can fit under maxPayloadBytes.
-
isOversized(
String json) → bool - Check if a single event JSON string exceeds the size limit.
Constants
- DELIMITER → const String
- delimiter → const String
- maxEventsPerBatch → const int
- Max events per batch.
- maxPayloadBytes → const int
- Max total payload size per batch in bytes (256KB).
- maxSingleEventBytes → const int
- Max size for a single event payload in bytes (200KB).